==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/kadu-core/protocols/services/chat-image-service.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
 * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "misc/path-conversion.h"

#include "debug.h"

#include "chat-image-service.h"

QString ChatImageService::imagesPath()
{
	return profilePath("images/");
}

ChatImageService::ChatImageService(QObject *parent) :
		QObject(parent)
{
}

bool ChatImageService::fitsHardSizeLimit(qint64 size)
{
	if (NoSizeLimit == hardSizeLimit())
		return true;
	return size <= hardSizeLimit();
}

bool ChatImageService::fitsSoftSizeLimit(qint64 size)
{
	if (!fitsHardSizeLimit(size))
		return false;
	if (NoSizeLimit == softSizeLimit())
		return true;
	return size <= softSizeLimit();
}

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/kadu-core/protocols/services/chat-image-service.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2011 Piotr Dąbrowski (ultr@ultr.pl)
 * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2010 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "misc/kadu-paths.h"

#include "debug.h"

#include "chat-image-service.h"

QString ChatImageService::imagesPath()
{
	return KaduPaths::instance()->profilePath() + QLatin1String("images/");
}

ChatImageService::ChatImageService(QObject *parent) :
		QObject(parent)
{
}

bool ChatImageService::fitsHardSizeLimit(qint64 size)
{
	if (NoSizeLimit == hardSizeLimit())
		return true;
	return size <= hardSizeLimit();
}

bool ChatImageService::fitsSoftSizeLimit(qint64 size)
{
	if (!fitsHardSizeLimit(size))
		return false;
	if (NoSizeLimit == softSizeLimit())
		return true;
	return size <= softSizeLimit();
}
